@@ -4,8 +4,9 @@ import cli.utilities.utils as utils
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
-@click.command(context_settings=CONTEXT_SETTINGS)
-def version():
+
+@click.command('version', context_settings=CONTEXT_SETTINGS)
+def cli_version():
     """
     Show the installed Dis.co CLI version.
 
