@@ -6,6 +6,17 @@ class DockerImageDetails(BaseModel):
     Docker image details.
     """
 
+    def __init__(self, data, is_default_docker=False):
+        super(DockerImageDetails, self).__init__(data)
+        self._is_default = is_default_docker
+
+    @property
+    def is_default(self):
+        """
+        Returns: True if this is the default docker image
+        """
+        return self._is_default
+
     @property
     def id(self):
         """
