@@ -3,6 +3,37 @@ Task Objects
 """
 from pathlib import Path
 from disco.core.utils import shorten_string
+from .base_controller import BaseController
+from .models import TaskAuditEvent
+
+
+class Task(BaseController):
+    """
+    Task methods
+    """
+
+    def __init__(self, task_id):
+        self.task_id = task_id
+        super().__init__()
+
+    def __repr__(self):
+        return '%s(%s)' % (type(self).__name__, repr(self.task_id))
+
+    def get_task_events_log(self):
+        """
+        Gets the activity log of the task.
+
+        Returns:
+            list(): List of all tasks events
+        """
+        result = self.query('fetchTaskAuditEvents', taskId=self.task_id)
+
+        if result is None:
+            return []
+
+        tasks_events = [TaskAuditEvent(event) for event in result['fetchTaskAuditEvents']]
+
+        return tasks_events
 
 
 class TaskResult:
