@@ -37,15 +37,16 @@ def get_results(job):
     return results
 
 
-def add_job_request(job_name, script_and_module_ids, input_files_ids, wait=False):
+def add_job_request(job_name, script_module_and_req_ids, input_files_ids, wait=False):
     machine_size = os.environ.get('DISCO_MACHINE_SIZE')
     cluster_id = os.environ.get('DISCO_CLUSTER_ID')
-    job = Job.create(script_file_id=script_and_module_ids[0],
+    job = Job.create(script_file_id=script_module_and_req_ids[0],
                      input_file_ids=input_files_ids,
-                     constants_file_ids=[script_and_module_ids[1]],
+                     constants_file_ids=[script_module_and_req_ids[1], script_module_and_req_ids[2]],
                      job_name=job_name,
                      cluster_id=cluster_id,
-                     cluster_instance_type=machine_size if machine_size is not None else 's')
+                     cluster_instance_type=machine_size if machine_size is not None else 's',
+                     upload_requirements_file=False)
     if wait:
         job.start()
         job.wait_for_finish()
