@@ -3,6 +3,7 @@ from tests.base_test import BaseTest
 
 
 class TestClusterDetails(BaseTest):
+
     def test_cluster_create(self):
         cluster_id = self.random_str('cluster_id')
         cluster_name = self.random_str('cluster_name')
@@ -30,3 +31,21 @@ class TestClusterDetails(BaseTest):
         assert cluster.is_active
         assert not cluster.cloud_offload_enabled
         assert cluster.is_last_connection_check_valid
+
+    def test_supports_register_files_from_bucket_supported(self):
+        cluster_id = self.random_str('cluster_id')
+        cluster_data = {
+            'id': cluster_id,
+            'type': self.random_from(['aws', 'gcp', 'azure'])
+        }
+        cluster = ClusterDetails(cluster_data, True)
+        assert cluster.supports_register_files_from_bucket is True
+
+    def test_supports_register_files_from_bucket_not_supported(self):
+        cluster_id = self.random_str('cluster_id')
+        cluster_data = {
+            'id': cluster_id,
+            'type': self.random_from(['packet', 'onPremise'])
+        }
+        cluster = ClusterDetails(cluster_data, True)
+        assert cluster.supports_register_files_from_bucket is False
